// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef FCITX5QT5DBUSADDONS_VERSION_H
#define FCITX5QT5DBUSADDONS_VERSION_H

#define FCITX5QT5DBUSADDONS_VERSION_STRING "5.0.17"
#define FCITX5QT5DBUSADDONS_VERSION_MAJOR 5
#define FCITX5QT5DBUSADDONS_VERSION_MINOR 0
#define FCITX5QT5DBUSADDONS_VERSION_PATCH 17
#define FCITX5QT5DBUSADDONS_VERSION ((5<<16)|(0<<8)|(17))

#endif
